# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import CustomUI, QuickReport, Screening

# Discovered Generic TypeVars:
T = TypeVar("T")
from . import (
    DataSourceGraphicsParameter,
    FieldFormat,
    GraphicsParameterAcceptsFieldValue,
    GraphicsParameterType,
    IDataSource,
    IDataSourceDesigner,
    IDataSourceGraphicsEdit,
    IDataSourceGraphicsParameter,
    IDataSourceTableFormat,
    IReportPreview,
)

# Stubs for namespace: Agilent.MassHunter.ReportBuilder.DataSource.Quant

class CompoundCalibrationGraphics(
    Agilent.MassHunter.ReportBuilder.DataSource.Quant.ICompoundCalibrationGraphics,
    System.IDisposable,
):  # Class
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        compoundId: int,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...
    def Dispose(self) -> None: ...

class CompoundPeakGraphics(
    System.IDisposable,
    Agilent.MassHunter.ReportBuilder.DataSource.Quant.ICompoundPeakGraphics,
):  # Class
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        compoundId: int,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        compoundId: int,
        x: float,
        y: float,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> None: ...
    def DrawOriginal(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        compoundId: int,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...
    def Dispose(self) -> None: ...

class DataSourceDesigner(
    IDataSourceDesigner,
    System.IDisposable,
    IDataSourceGraphicsEdit,
    IDataSourceTableFormat,
    IReportPreview,
):  # Class
    def __init__(self) -> None: ...

    DataSourceType: System.Type  # readonly

    def GetFieldNames(self, dataName: str) -> List[str]: ...
    def GetDataNames(self) -> List[str]: ...
    def SetupPreview(
        self, parameterPath: str, parent: System.Windows.Window, alwaysShowUI: bool
    ) -> bool: ...
    def DefaultFieldFormat(
        self, dataName: str, fieldName: str, format: FieldFormat
    ) -> bool: ...
    def GetGraphicsNames(self) -> List[str]: ...
    def GeneratePreview(
        self,
        templatePath: str,
        template: Agilent.MassHunter.ReportBuilder.Template.IReportTemplate,
        parameterFile: str,
        outputPath: str,
    ) -> None: ...
    def GetDisplayName(self, name: str) -> str: ...
    def GetParameters(self, name: str) -> List[IDataSourceGraphicsParameter]: ...
    def Dispose(self) -> None: ...
    def GetCustomUI(self) -> T: ...

class DataSourceFactory:  # Class
    @staticmethod
    def CreateDataSource(
        template: Agilent.MassHunter.ReportBuilder.Template.IReportTemplate,
        presentationState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.PresentationState,
        dtstart: System.DateTime,
    ) -> Agilent.MassHunter.ReportBuilder.DataSource.Quant.IQuantDataSourceBase: ...

class GraphicsParameter(
    IDataSourceGraphicsParameter, DataSourceGraphicsParameter
):  # Class
    def __init__(
        self,
        graphicsName: str,
        name: str,
        category: str,
        displayName: str,
        parameterType: GraphicsParameterType,
        acceptsFieldValue: GraphicsParameterAcceptsFieldValue,
    ) -> None: ...

    GraphicsName: str

    def GetCustomEditor(
        self,
        application: Agilent.MassHunter.ReportBuilder.Application.IApplication,
        editorBaseType: System.Type,
    ) -> Any: ...
    @staticmethod
    def LoadGraphicsParameters(
        document: System.Xml.XPath.XPathDocument,
        graphicsName: str,
        rmgr: System.Resources.ResourceManager,
    ) -> List[IDataSourceGraphicsParameter]: ...

class ICompoundCalibrationGraphics(object):  # Interface
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        compoundId: int,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...

class ICompoundPeakGraphics(object):  # Interface
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        compoundId: int,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        compoundId: int,
        x: float,
        y: float,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> None: ...
    def DrawOriginal(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        compoundId: int,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...

class IPeakOverlayGraphics(object):  # Interface
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        compoundId: int,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        compoundId: int,
        x: float,
        y: float,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> None: ...

class IPeakSpectrumGraphics(object):  # Interface
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        compoundId: int,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        compoundId: int,
        x: float,
        y: float,
        width: float,
        height: float,
        minmz: Optional[float],
        maxmz: Optional[float],
    ) -> None: ...

class IQualifierPeakGraphics(object):  # Interface
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        compoundId: int,
        qualifierId: int,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        compoundId: int,
        qualifierId: int,
        x: float,
        y: float,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> None: ...
    def DrawOriginal(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        compoundId: int,
        qualifierId: int,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...

class IQuantDataSource(
    Agilent.MassHunter.ReportBuilder.DataSource.Quant.IQuantDataSourceBase,
    IDataSource,
    System.IDisposable,
):  # Interface
    CompoundCalibrationGraphics: (
        Agilent.MassHunter.ReportBuilder.DataSource.Quant.ICompoundCalibrationGraphics
    )  # readonly
    CompoundPeakGraphics: (
        Agilent.MassHunter.ReportBuilder.DataSource.Quant.ICompoundPeakGraphics
    )  # readonly
    PeakOverlayGraphics: (
        Agilent.MassHunter.ReportBuilder.DataSource.Quant.IPeakOverlayGraphics
    )  # readonly
    PeakSpectrumGraphics: (
        Agilent.MassHunter.ReportBuilder.DataSource.Quant.IPeakSpectrumGraphics
    )  # readonly
    QualifierPeakGraphics: (
        Agilent.MassHunter.ReportBuilder.DataSource.Quant.IQualifierPeakGraphics
    )  # readonly
    SampleGraphics: (
        Agilent.MassHunter.ReportBuilder.DataSource.Quant.ISampleGraphics
    )  # readonly

class IQuantDataSourceBase(IDataSource, System.IDisposable):  # Interface
    BatchFile: str  # readonly
    BatchFolder: str  # readonly
    CompoundFilter: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.IDataFilter
    )
    DataSet: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet
    )  # readonly
    FixedGraphics: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IFixedGraphics
    )
    PresentationState: (
        Agilent.MassHunter.Quantitative.UIModel.IPresentationState
    )  # readonly
    SampleFilter: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.IDataFilter
    )

class ISampleGraphics(object):  # Interface
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        x: float,
        y: float,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> None: ...
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        x: float,
        y: float,
        width: float,
        height: float,
        deviceName: str,
        ordinalNumber: int,
        signalName: str,
    ) -> None: ...
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        x: float,
        y: float,
        width: float,
        height: float,
        deviceName: str,
        ordinalNumber: int,
        signalName: str,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> None: ...
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        x: float,
        y: float,
        width: float,
        height: float,
        scanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType,
    ) -> None: ...
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        x: float,
        y: float,
        width: float,
        height: float,
        scanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> None: ...

class MSScanTypeRow:  # Class
    def __init__(self) -> None: ...

    BatchID: int
    MSScanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType
    SampleID: int

class PeakLabelTypesEditor(System.Drawing.Design.UITypeEditor):  # Class
    def __init__(
        self, application: Agilent.MassHunter.ReportBuilder.Application.IApplication
    ) -> None: ...
    def EditValue(
        self,
        context: System.ComponentModel.ITypeDescriptorContext,
        provider: System.IServiceProvider,
        value_: Any,
    ) -> Any: ...
    def GetEditStyle(
        self, context: System.ComponentModel.ITypeDescriptorContext
    ) -> System.Drawing.Design.UITypeEditorEditStyle: ...

class PeakOverlayGraphics(
    System.IDisposable,
    Agilent.MassHunter.ReportBuilder.DataSource.Quant.IPeakOverlayGraphics,
):  # Class
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        compoundId: int,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        compoundId: int,
        x: float,
        y: float,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> None: ...
    def Dispose(self) -> None: ...

class PeakSpectrumGraphics(
    System.IDisposable,
    Agilent.MassHunter.ReportBuilder.DataSource.Quant.IPeakSpectrumGraphics,
):  # Class
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        compoundId: int,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        compoundId: int,
        x: float,
        y: float,
        width: float,
        height: float,
        minmz: Optional[float],
        maxmz: Optional[float],
    ) -> None: ...
    def Dispose(self) -> None: ...

class QualifierPeakGraphics(
    Agilent.MassHunter.ReportBuilder.DataSource.Quant.IQualifierPeakGraphics,
    System.IDisposable,
):  # Class
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        compoundId: int,
        qualifierId: int,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        compoundId: int,
        qualifierId: int,
        x: float,
        y: float,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> None: ...
    def DrawOriginal(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        compoundId: int,
        qualifierId: int,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...
    def Dispose(self) -> None: ...

class QuantDataSource(
    Agilent.MassHunter.ReportBuilder.DataSource.Quant.IQuantDataSource,
    System.IDisposable,
    IDataSource,
    Agilent.MassHunter.ReportBuilder.DataSource.Quant.IQuantDataSourceBase,
):  # Class
    def __init__(
        self,
        presentationState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.PresentationState,
        reportTime: System.DateTime,
    ) -> None: ...

    BatchFile: str  # readonly
    BatchFolder: str  # readonly
    CompoundCalibrationGraphics: (
        Agilent.MassHunter.ReportBuilder.DataSource.Quant.ICompoundCalibrationGraphics
    )  # readonly
    CompoundFilter: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.IDataFilter
    )
    CompoundPeakGraphics: (
        Agilent.MassHunter.ReportBuilder.DataSource.Quant.ICompoundPeakGraphics
    )  # readonly
    DataSet: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet
    )  # readonly
    FixedGraphics: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IFixedGraphics
    )
    PeakOverlayGraphics: (
        Agilent.MassHunter.ReportBuilder.DataSource.Quant.IPeakOverlayGraphics
    )  # readonly
    PeakSpectrumGraphics: (
        Agilent.MassHunter.ReportBuilder.DataSource.Quant.IPeakSpectrumGraphics
    )  # readonly
    PresentationState: (
        Agilent.MassHunter.Quantitative.UIModel.IPresentationState
    )  # readonly
    QualifierPeakGraphics: (
        Agilent.MassHunter.ReportBuilder.DataSource.Quant.IQualifierPeakGraphics
    )  # readonly
    ReportStartTime: System.DateTime
    SampleFilter: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.IDataFilter
    )
    SampleGraphics: (
        Agilent.MassHunter.ReportBuilder.DataSource.Quant.ISampleGraphics
    )  # readonly

    def DrawGraphics(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        x: float,
        y: float,
        width: float,
        height: float,
        name: str,
        parameters: List[System.Collections.Generic.KeyValuePair[str, Any]],
    ) -> None: ...
    def SelectSignals(
        self,
        context: Agilent.MassHunter.ReportBuilder.Engine.IReportContext,
        dataBinding: Agilent.MassHunter.ReportBuilder.Template.IDataBinding,
    ) -> List[Any]: ...
    def GetFieldCaption(self, bindingName: str, fieldName: str) -> str: ...
    def Select(
        self,
        context: Agilent.MassHunter.ReportBuilder.Engine.IReportContext,
        dataBinding: Agilent.MassHunter.ReportBuilder.Template.IDataBinding,
    ) -> List[Any]: ...
    def SelectMSScanTypes(
        self,
        context: Agilent.MassHunter.ReportBuilder.Engine.IReportContext,
        dataBiding: Agilent.MassHunter.ReportBuilder.Template.IDataBinding,
    ) -> List[Any]: ...
    def LocalizeFieldValue(self, dataName: str, fieldName: str, value_: Any) -> str: ...
    def GetFieldFormat(self, bindingName: str, fieldName: str) -> str: ...
    def Dispose(self) -> None: ...

class SampleGraphics(
    System.IDisposable,
    Agilent.MassHunter.ReportBuilder.DataSource.Quant.ISampleGraphics,
):  # Class
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        x: float,
        y: float,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> None: ...
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        x: float,
        y: float,
        width: float,
        height: float,
        scanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType,
    ) -> None: ...
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        x: float,
        y: float,
        width: float,
        height: float,
        scanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> None: ...
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        x: float,
        y: float,
        width: float,
        height: float,
        deviceName: str,
        ordinalNumber: int,
        signalName: str,
    ) -> None: ...
    @overload
    def Draw(
        self,
        canvas: Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
        batchId: int,
        sampleId: int,
        x: float,
        y: float,
        width: float,
        height: float,
        deviceName: str,
        ordinalNumber: int,
        signalName: str,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> None: ...
    def Dispose(self) -> None: ...

class SetupPreviewWindow(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Window,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IWindowService,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(
        self,
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
    ) -> None: ...

    BatchFile: str
    BatchFolder: str
    InstrumentType: Agilent.MassSpectrometry.DataAnalysis.Quantitative.InstrumentType
    MaxNumPages: int

    def InitializeComponent(self) -> None: ...

class SignalRow:  # Class
    def __init__(self) -> None: ...

    BatchID: int
    DeviceName: str  # readonly
    OrdinalNumber: int  # readonly
    SampleID: int
    SignalName: str  # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")
from . import IDataFilter

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.Filters

class SimpleColumnFilter(Generic[T], IDataFilter):  # Class
    def __init__(self, name: str, values: List[T]) -> None: ...

    FilterString: str  # readonly
    SupportsFilterString: bool  # readonly

    def Match(self, row: System.Data.DataRow) -> bool: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Agilent.MassSpectrometry.DataAnalysis import (
    FormulaGenerationRules,
    FormulaGenerator,
    IComposition,
    IIonSpeciesDetails,
    IModificationSpecies,
    IPrecursor,
    IsotopePattern,
    ITargetFormulaTracker,
    MassIsotopeChoice,
    SpectralPeak,
)
from .BasicTypes import FragmentIon

# Stubs for namespace: CompositionCalculatorEngine

class ChemicalElementLimitsFactory:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def ChemicalElementLimits(
        massChoice: MassIsotopeChoice, rules: FormulaGenerationRules
    ) -> CompositionCalculatorEngine.IChemicalElementLimits: ...

class FragmentFormulaGenerator:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def GetProductsForGivenPrecursor(
        precursorFormula: str,
        spectrum: List[FragmentIon],
        productMassAccuray: List[float],
        precursorSpecies: IModificationSpecies,
        parameters: FormulaGenerator.UserParameters,
    ) -> IPrecursor: ...
    @staticmethod
    def GetPrecursors(
        spectrum: List[FragmentIon],
        precursorPeaks: List[SpectralPeak],
        precursorSpecies: IModificationSpecies,
        precursorLowestIsotopeMZ: float,
        precursorZ: int,
        parameters: FormulaGenerator.UserParameters,
        productMassAccuray: List[float],
        precursorNeutralMass: float,
    ) -> List[IPrecursor]: ...

class IChemicalElementLimits(object):  # Interface
    def MaxWtFraction(self, elementSymbol: str, neutralMass: float) -> float: ...
    def MinCount(self, elementSymbol: str, neutralMass: float) -> int: ...
    def MaxCount(self, elementSymbol: str, neutralMass: float) -> int: ...

class IInternalComposition(IComposition):  # Interface
    IsotopePattern: IsotopePattern
    IsotopePatternIonSpecies: IIonSpeciesDetails
    ModificationSpecies: IModificationSpecies

    def SetMatchingScore(self, v: float) -> None: ...
    def SetErrors(
        self, averageMzError: float, heightError: float, s1Error: float, s2Error: float
    ) -> None: ...
    def SetScoreDetail(
        self, monoMassScore: float, intensityPatternScore: float, mzSpacingScore: float
    ) -> None: ...

class TargetFormulaTracker(ITargetFormulaTracker):  # Class
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import TitledPanel

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Controls.SpectrumPlot

class SpectrumPlotControl(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IBindableComponent,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    Agilent.MassSpectrometry.GUI.Plot.PlotControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    CanCopy: bool  # readonly
    CanCut: bool  # readonly
    CanDelete: bool  # readonly
    CanPaste: bool  # readonly
    DrawMolecularStructure: bool
    MaxNumRowsPerPage: int
    SelectedSpectrumKeys: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Utils.SpectrumKey
    ]  # readonly
    UIContext: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.UIContext

    def Copy(self) -> None: ...
    def GetAutoScaleRangeY(
        self, pane: Agilent.MassSpectrometry.GUI.Plot.Pane, minX: float, maxX: float
    ) -> Agilent.MassSpectrometry.GUI.Plot.PlotRange: ...
    def GetAutoScaleRangeX(
        self, pane: Agilent.MassSpectrometry.GUI.Plot.Pane
    ) -> Agilent.MassSpectrometry.GUI.Plot.PlotRange: ...
    def Cut(self) -> None: ...
    def Delete(self) -> None: ...
    def Paste(self) -> None: ...

    # Nested Types

    class QualSpectra:  # Class
        def __init__(self) -> None: ...

        DetailsArray: List[
            Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Controls.SpectrumPlot.SpectrumPlotControl.QualSpectraDetails
        ]

    class QualSpectraDetails:  # Class
        def __init__(self) -> None: ...

        CollisionEnergy: Optional[float]
        FragmentorVoltage: Optional[float]
        FxData: (
            Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Controls.SpectrumPlot.SpectrumPlotControl.QualSpectraFxData
        )
        InstrumentType: str
        IonPolarity: Optional[Agilent.MassSpectrometry.DataAnalysis.IonPolarity]
        IonizationMode: Optional[Agilent.MassSpectrometry.DataAnalysis.IonizationMode]
        RetentionTime: Optional[float]
        ScanType: Optional[Agilent.MassSpectrometry.DataAnalysis.MSScanType]
        SelectedMz: Optional[float]
        name: str

    class QualSpectraFxData:  # Class
        def __init__(self) -> None: ...

        Points: List[
            Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Controls.SpectrumPlot.SpectrumPlotControl.QualSpectraFxDataPoint
        ]

    class QualSpectraFxDataPoint:  # Class
        def __init__(self) -> None: ...

        i: int
        x: float
        y: float

class SpectrumPlotPane(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    TitledPanel,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    SpectrumPlotControl: (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Controls.SpectrumPlot.SpectrumPlotControl
    )  # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Definitions

class IMass_TimeSeparatedObject(object):  # Interface
    Abundance: float  # readonly
    Height: float  # readonly
    ID: str  # readonly
    Mass: float  # readonly
    SeparationTime: float  # readonly

class UnitConversion:  # Class
    def __init__(self) -> None: ...

    RetentionTime: float = ...  # static # readonly

    UseOldVoluemScaling: bool  # static
    Volume: float  # static # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Models import ICalibrationRangeItem, IIonGroupPlotSeries

# Stubs for namespace: Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Views

class CalibrationRangeView(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class CalibrationView(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class CompoundsView(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class IonGroupPlotControl(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Markup.IHaveResources,
    System.Windows.Controls.Control,
    System.Windows.Media.Animation.IAnimatable,
    Agilent.MassHunter.Quantitative.PlotControl.IAxisContainer,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...

    PlotSeriesProperty: System.Windows.DependencyProperty  # static
    SelectedRangeProperty: System.Windows.DependencyProperty  # static
    SelectedSeriesProperty: System.Windows.DependencyProperty  # static

    PlotSeries: List[IIonGroupPlotSeries]
    SelectedRange: ICalibrationRangeItem
    SelectedSeries: IIonGroupPlotSeries

    @staticmethod
    def IsIntersect(
        p1x: float,
        p1y: float,
        p2x: float,
        p2y: float,
        p3x: float,
        p3y: float,
        p4x: float,
        p4y: float,
        p5x: float,
        p5y: float,
        p6x: float,
        p6y: float,
    ) -> bool: ...
    @staticmethod
    def CCW(
        x0: float, y0: float, x1: float, y1: float, x2: float, y2: float
    ) -> int: ...
    def RecalcRects(self) -> None: ...
    def CreateTypeface(self) -> System.Windows.Media.Typeface: ...
    @staticmethod
    def Norm(x: float, y: float) -> float: ...
    @staticmethod
    def Dot(x1: float, y1: float, x2: float, y2: float) -> float: ...
    @staticmethod
    def Cross(x1: float, y1: float, x2: float, y2: float) -> float: ...
    def Invalidate(self) -> None: ...

class IonGroupView(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...

    DataGrid: System.Windows.Controls.DataGrid  # readonly

    def InitializeComponent(self) -> None: ...

class QualifiersView(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import (
    BatchTable,
    ColumnLabels,
    Configuration,
    General,
    MainView,
    Manage,
    Outliers,
    Ribbon,
    SampleType,
    Utils,
    ViewModel,
)

# Stubs for namespace: Agilent.MassHunter.Quantitative.Startup.Edit

class App(
    System.Windows.Application,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IHaveResources,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...
    @staticmethod
    def Main() -> None: ...

class CommandLine:  # Class
    def __init__(self) -> None: ...

    Culture: str

class EditException(
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
    System.Exception,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, innerException: System.Exception) -> None: ...
    @overload
    def __init__(
        self,
        info: System.Runtime.Serialization.SerializationInfo,
        context: System.Runtime.Serialization.StreamingContext,
    ) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Compliance import ICompliance

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceConfiguration

class CheckListControl(
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UserControl,
):  # Class
    def __init__(self) -> None: ...

    ContextMenuStrip: System.Windows.Forms.ContextMenuStrip
    StateImageList: System.Windows.Forms.ImageList
    TitleText: str

    def ClearItems(self) -> None: ...
    def SelectItem(self, key: str) -> None: ...
    def SetItemState(
        self, key: str, state: System.Windows.Forms.CheckState
    ) -> None: ...
    def GetSelectedItems(self) -> List[str]: ...
    def GetItemKey(self, index: int) -> str: ...
    def EndUpdate(self) -> None: ...
    def SetItem(
        self, key: str, text: str, state: System.Windows.Forms.CheckState
    ) -> None: ...
    def BeginUpdate(self) -> None: ...

    ItemCheck: System.Windows.Forms.ItemCheckEventHandler  # Event

class CommandLine:  # Class
    def __init__(self) -> None: ...

    Culture: str

class CommandSettingsControl(
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UserControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceConfiguration.IMapView,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.IWin32Window,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
):  # Class
    def __init__(self) -> None: ...

class CommandTreeControl(
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UserControl,
):  # Class
    def __init__(self) -> None: ...

    TreeNodeAfterSelect: System.EventHandler  # Event

class DataType(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
    Command: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceConfiguration.DataType
    ) = ...  # static # readonly
    CommandGroup: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceConfiguration.DataType
    ) = ...  # static # readonly
    Settings: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceConfiguration.DataType
    ) = ...  # static # readonly
    Unknown: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceConfiguration.DataType
    ) = ...  # static # readonly

class EditorForm(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, compliance: ICompliance) -> None: ...

class SettingsControl(
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UserControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceConfiguration.IMapView,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.IWin32Window,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
):  # Class
    def __init__(self) -> None: ...

class TitleLabel(
    System.IDisposable,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.ComponentModel.ISynchronizeInvoke,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.Label,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
):  # Class
    def __init__(self) -> None: ...

    BackColor2: System.Drawing.Color



# type: ignore[attr-defined]
from typing import Annotated, List, Optional, Tuple

from enum import Enum
from pathlib import Path

import typer
from rich.console import Console

from mh_operator import version
from mh_operator.utils.code_generator import function_to_string
from mh_operator.utils.common import logger
from mh_operator.utils.ironpython27 import (
    __DEFAULT_MH_BIN_DIR__,
    __DEFAULT_PY275_EXE__,
    CaptureType,
    run_ironpython_script,
)


class Color(str, Enum):
    white = "white"
    red = "red"
    cyan = "cyan"
    magenta = "magenta"
    yellow = "yellow"
    green = "green"


app = typer.Typer(
    name="mh-operator",
    help="Awesome `mh-operator` provide interfaces and common routines for the Agilent MassHunter official SDK.",
    add_completion=False,
)
console = Console()


def version_callback(print_version: bool) -> None:
    """Print the version of the package."""
    if print_version:
        console.print(f"[yellow]mh-operator[/] version: [bold blue]{version}[/]")
        raise typer.Exit()


@app.command(name="install")
def install_legacy_import_helper(
    mh: Annotated[
        Path,
        typer.Option(
            help="The bin path of the installed Mass Hunter",
        ),
    ] = __DEFAULT_MH_BIN_DIR__,
    ipy: Annotated[
        Path,
        typer.Option(
            help="The ipy.exe path of the installed Python2.7",
        ),
    ] = __DEFAULT_PY275_EXE__,
    symlink: Annotated[
        bool,
        typer.Option(
            help="Do symlink instead of copy",
        ),
    ] = False,
):
    """Install the mh_operator.legacy into Python2.7 environment"""

    legacy_script = Path(__file__).parent / "legacy" / "__init__.py"

    assert Path(mh).exists()

    mh_exe_path = {
        "UAC": Path(mh) / "UnknownsAnalysisII.Console.exe",
        "LEC": Path(mh) / "LibraryEdit.Console.exe",
        "QC": Path(mh) / "QuantConsole.exe",
    }

    def install_to(tgt, src):
        if tgt.exists():
            tgt.unlink()

        logger.debug(f"{'Symlink' if symlink else 'Copy'} `{src}` to `{tgt}`")
        if symlink:
            tgt.symlink_to(src)
        else:
            tgt.write_bytes(src.read_bytes())

    logger.info(f"Install mh-operator legacy for {ipy}")
    install_to(
        Path(ipy).parent / "Lib" / "site-packages" / "mh_operator_legacy.py",
        legacy_script,
    )

    for interpreter, exe_path in mh_exe_path.items():
        logger.info(f"Install mh-operator legacy for {interpreter}: {exe_path}")
        _, stdout, _ = run_ironpython_script(
            legacy_script,
            exe_path,
            python_paths=[str(Path(__file__).parent / "..")],
            extra_envs=["MH_CONSOLE_COMMAND_STRING=print(repr(sys.path))"],
            capture_type=CaptureType.SEPERATE,
        )
        import ast

        tgt_path = next(
            p for p in ast.literal_eval(stdout.splitlines()[-1]) if "MassHunter" in p
        )

        install_to(Path(tgt_path) / "mh_operator_legacy.py", legacy_script)


@app.command(name="extract-uaf")
def extract_mass_hunter_analysis_file(
    uaf: Annotated[
        Path,
        typer.Argument(
            help="The Mass Hunter analysis file (.uaf)",
        ),
    ],
    mh: Annotated[
        Path,
        typer.Option(
            help="The bin path of the installed Mass Hunter",
        ),
    ] = __DEFAULT_MH_BIN_DIR__,
    processed: Annotated[
        bool,
        typer.Option(
            help="Do processing on the tables inside MassHunter script",
        ),
    ] = False,
    output: Annotated[
        str,
        typer.Option(
            "-o",
            "--output",
            help="The output file path or '-' for stdout",
        ),
    ] = "-",
):
    """Export all data tables from Mass Hunter analysis file to json/xlsx"""
    legacy_script = Path(__file__).parent / "legacy" / "__init__.py"

    uac_exe = Path(mh) / "UnknownsAnalysisII.Console.exe"
    assert Path(uac_exe).exists()
    assert Path(uaf).exists()

    @function_to_string(return_type="asis", oneline=True)
    def _commands(uaf: str, processed: bool):
        from mh_operator.legacy.common import global_state

        global_state.UADataAccess = UADataAccess
        from mh_operator.legacy.UnknownsAnalysis import export_analysis

        return export_analysis(uaf).to_json(processed)

    commands = _commands(str(Path(uaf).absolute()), processed)
    logger.debug(f"use {legacy_script} to exec code '{commands}'")

    returncode, stdout, stderr = run_ironpython_script(
        legacy_script,
        uac_exe,
        python_paths=[str(uac_exe.parent), str(Path(__file__).parent / "..")],
        extra_envs=[f"MH_CONSOLE_COMMAND_STRING={commands}"],
        capture_type=CaptureType.SEPERATE,
    )
    if returncode != 0:
        logger.info(f"UAC return with {returncode} and stderr:\n{stderr}")

    logger.debug(f"UAC return stdout:\n {stdout}")
    import json

    json_data = json.loads(stdout.split("\n", maxsplit=2)[-1])
    if output == "-":
        print(json.dumps(json_data, indent=2))
    elif output.endswith(".json"):
        with open(output, "w") as fp:
            json.dump(json_data, fp)
    elif output.endswith(".sqlite"):
        import sqlite3

        import pandas as pd

        with sqlite3.connect(output) as conn:
            for t, v in json_data.items():
                pd.DataFrame(v).to_sql(t, con=conn, if_exists="replace")
    elif output.endswith(".xlsx"):
        import pandas as pd

        with pd.ExcelWriter(output, engine="xlsxwriter") as writer:
            for t, v in json_data.items():
                pd.DataFrame(v).to_excel(writer, sheet_name=t, index=False)


@app.command(name="analysis")
def analysis_samples(
    samples: Annotated[
        list[Path],
        typer.Argument(
            help="The Mass Hunter analysis file name (.D)",
        ),
    ],
    analysis_method: Annotated[
        Path,
        typer.Option(
            "-m",
            "--method",
            help="The Mass Hunter analysis method path (.m)",
        ),
    ] = "Process.m",
    output: Annotated[
        str,
        typer.Option(
            "-o",
            "--output",
            help="The Mass Hunter analysis file name (.uaf)",
        ),
    ] = "batch.uaf",
    report_method: Annotated[
        Path,
        typer.Option(
            "--report-method",
            help="The Mass Hunter report method path (.m)",
        ),
    ] = None,
    istd_rt: Annotated[
        float,
        typer.Option(
            "--istd-rt",
            help="The ISTD compound retention time (min.)",
        ),
    ] = None,
    istd_name: Annotated[
        str,
        typer.Option(
            "--istd-name",
            help="The ISTD compound name",
        ),
    ] = None,
    istd_value: Annotated[
        float,
        typer.Option(
            "--istd-value",
            help="The ISTD compound concentration",
        ),
    ] = None,
    mh: Annotated[
        Path,
        typer.Option(
            help="The bin path of the installed Mass Hunter",
        ),
    ] = __DEFAULT_MH_BIN_DIR__,
):
    """Analysis samples with Mass Hunter"""
    legacy_script = Path(__file__).parent / "legacy" / "__init__.py"

    uac_exe = Path(mh) / "UnknownsAnalysisII.Console.exe"
    assert Path(uac_exe).exists()

    @function_to_string(return_type="none", oneline=False)
    def _commands(
        uaf_name: str,
        sample_paths: list[tuple[tuple, dict]],
        analysis_method: str,
        report_method: str | None = None,
        istd_params: dict | None = None,
    ):
        from mh_operator.legacy.common import global_state

        global_state.UADataAccess = UADataAccess
        from mh_operator.legacy.UnknownsAnalysis import ISTD, Sample, analysis_samples

        if istd_params is not None:
            istd = ISTD(**istd_params)
        else:
            istd = None

        analysis_samples(
            uaf_name,
            [Sample(*args, **kwargs) for args, kwargs in sample_paths],
            analysis_method,
            istd=istd,
            report_method=report_method,
        )

    if istd_rt is not None:
        assert (
            istd_name is not None and istd_value is not None
        ), "rt, name, and value must be all set for ISTD to work"
        istd_params = dict(
            istd_rt=istd_rt,
            istd_name=istd_name,
            istd_value=istd_value,
        )
    else:
        istd_params = None

    commands = _commands(
        output,
        [((str(Path(s).absolute()),), {"type": "Sample"}) for s in samples],
        str(Path(analysis_method).absolute()),
        report_method=(
            str(Path(report_method).absolute()) if report_method is not None else None
        ),
        istd_params=istd_params,
    )
    logger.debug(f"use {legacy_script} to exec code '{commands}'")

    returncode, _, _ = run_ironpython_script(
        legacy_script,
        uac_exe,
        python_paths=[str(uac_exe.parent), str(Path(__file__).parent / "..")],
        extra_envs=[f"MH_CONSOLE_COMMAND_STRING={commands}", f"MH_BIN_DIR={mh}"],
        capture_type=CaptureType.NONE,
    )
    if returncode != 0:
        logger.info(f"UAC return with {returncode}")


if __name__ == "__main__":
    app()



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import UIState

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIFImpls.Printing

class PrintPlotDocument(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.PrintGraphicsDocument,
    System.ComponentModel.IComponent,
    System.IDisposable,
):  # Class
    def __init__(
        self,
        uiState: UIState,
        activePlot: Agilent.MassSpectrometry.GUI.Plot.PlotControl,
        printerSettings: System.Drawing.Printing.PrinterSettings,
        pageSettings: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.PlotPageSettings,
        preview: bool,
        reportBuilderTemplate: str,
    ) -> None: ...

    Anchoring: bool
    Column: int
    PageNumber: int  # readonly
    PlotControl: Agilent.MassSpectrometry.GUI.Plot.PlotControl  # readonly
    ReportBuilderTemplate: str  # readonly
    Row: int
    UIState: UIState  # readonly

    def DrawPage(
        self,
        graphics: System.Drawing.Graphics,
        pageBounds: System.Drawing.Rectangle,
        marginBounds: System.Drawing.RectangleF,
        row: int,
        col: int,
    ) -> None: ...
    def RenderGraphics(
        self,
        graphics: Agilent.MassSpectrometry.GUI.Plot.IGraphics,
        x: float,
        y: float,
        w: float,
        h: float,
        name: str,
    ) -> None: ...
    def GetNumPages(self) -> int: ...
    def PrintToPdf(self, stream: System.IO.Stream) -> None: ...



from mh_operator.utils.code_generator import function_to_string


@function_to_string(return_type="repr", oneline=True)
def simple_math(a, b=2):
    c = a * b
    d = c + 10
    return d


@function_to_string(return_type="repr", oneline=False)
def if_logic(x, y):
    res = 0
    if x > y + 2:
        res = x - y
    else:
        res = x + y
    return res


@function_to_string(return_type="json", oneline=False)
def fstring_and_return_transform(name, val):
    msg = f"Hello {name}, your calculated value is {val}."
    return {"message": msg, "original_age": val}  # Complex return


@function_to_string(return_type="none")
def no_return(val):
    if val > 10:
        processed = val * 100


@function_to_string()
def only_pass():
    pass


@function_to_string(return_type="repr", oneline=False)
def becomes_pass(a):
    if a > 100 and a < 0:  # Always false
        b = 10
    return None


def test_simplify_pure_function_ast():
    print("--- simple_math(5) ---")
    print(simple_math(5))
    # Expected: c = 10; d = 20; import json; print(json.dumps(20))

    print("\n--- if_logic(10, 5) ---")
    print(if_logic(10, 5))
    # Expected: res = 5; import json; print(json.dumps(5))

    print("\n--- if_logic(5, 5) ---")
    print(if_logic(5, 5))
    # Expected: res = 10; import json; print(json.dumps(10))

    print("\n--- fstring_and_return_transform('User', 25) ---")
    print(fstring_and_return_transform("User", 25))
    # Expected: val = 30; msg = f"Hello User, your calculated value is 30."; import json; print(json.dumps({'message': msg, 'original_age': 25}))
    # The f-string itself might not fully simplify if 'name' remains symbolic.

    print("\n--- no_return(15) ---")
    print(no_return(15))
    # Expected: processed = 1500 (if print inside is removed or simplified)
    # Or if the print is symbolic: if 15 > 10: processed = 1500; print(f"Processed value: {processed}")
    # Current simplifier doesn't remove print statements. If no return, output is just the simplified body.

    print("\n--- only_pass() ---")
    print(only_pass())
    # Expected: pass

    print("\n--- becomes_pass(10) ---")
    print(becomes_pass(10))
    # Expected: import json; print(json.dumps(None)); pass (or just the print if pass gets fully optimized out)
    # More likely: import json; print(json.dumps(None)) if last pass auto-removed

    # Test parameter reassignment error
    print("\n--- reassign(5) ---")
    try:

        @function_to_string(return_type="repr", oneline=False)
        def reassign(a):
            for a in range(10):
                pass  # This should cause an assertion error

            return a

        print(reassign(5))
    except Exception as e:  # Catching the broad error from the decorator for testing
        print(f"Caught expected error: {e}")



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Schema

class Batch:  # Class
    AcqDateTime: str = ...  # static # readonly
    AcqMethod: str = ...  # static # readonly
    BatchID: str = ...  # static # readonly
    CalibrationReferenceSampleID: str = ...  # static # readonly
    DataFileName: str = ...  # static # readonly
    DataPathName: str = ...  # static # readonly
    Dilution: str = ...  # static # readonly
    EquilibrationTime: str = ...  # static # readonly
    InjectorVolume: str = ...  # static # readonly
    LevelName: str = ...  # static # readonly
    MatrixType: str = ...  # static # readonly
    QuantitationMessage: str = ...  # static # readonly
    SampleAmount: str = ...  # static # readonly
    SampleGroup: str = ...  # static # readonly
    SampleID: str = ...  # static # readonly
    SampleName: str = ...  # static # readonly
    SamplePosition: str = ...  # static # readonly
    SampleType: str = ...  # static # readonly
    TableName: str = ...  # static # readonly
    TotalSampleAmount: str = ...  # static # readonly

class BatchAttributes:  # Class
    ApplyMultiplierISTD: str = ...  # static # readonly
    ApplyMultiplierSurrogate: str = ...  # static # readonly
    ApplyMultiplierTarget: str = ...  # static # readonly
    BandName: str = ...  # static # readonly
    BatchState: str = ...  # static # readonly
    BracketingType: str = ...  # static # readonly
    CorrelationWindow: str = ...  # static # readonly
    DataVersion: str = ...  # static # readonly
    FeatureDetection: str = ...  # static # readonly
    HashCode: str = ...  # static # readonly
    IgnorePeaksNotFound: str = ...  # static # readonly
    LibraryMethodPathFileName: str = ...  # static # readonly
    LibraryPathFileName: str = ...  # static # readonly
    NonReferenceWindow: str = ...  # static # readonly
    NonReferenceWindowPercentOrMinutes: str = ...  # static # readonly
    RefLibraryPathFileName: str = ...  # static # readonly
    RefLibraryPatternPathFileName: str = ...  # static # readonly
    ReferenceWindow: str = ...  # static # readonly
    ReferenceWindowPercentOrMinutes: str = ...  # static # readonly
    SchemaVersion: str = ...  # static # readonly
    TimeStamp: str = ...  # static # readonly

class Calibration:  # Class
    CalibrationName: str = ...  # static # readonly
    CalibrationSTDPathName: str = ...  # static # readonly
    CalibrationType: str = ...  # static # readonly
    LevelAverageCounter: str = ...  # static # readonly
    LevelConcentration: str = ...  # static # readonly
    LevelEnable: str = ...  # static # readonly
    LevelID: str = ...  # static # readonly
    LevelName: str = ...  # static # readonly
    LevelRSD: str = ...  # static # readonly
    LevelResponse: str = ...  # static # readonly
    LevelResponseFactor: str = ...  # static # readonly
    TableName: str = ...  # static # readonly

class Peak:  # Class
    Accuracy: str = ...  # static # readonly
    Area: str = ...  # static # readonly
    AreaCorrectionResponse: str = ...  # static # readonly
    BaselineEnd: str = ...  # static # readonly
    BaselineStandardDeviation: str = ...  # static # readonly
    BaselineStart: str = ...  # static # readonly
    CalculatedConcentration: str = ...  # static # readonly
    DeltaRetentionTime_: str = ...  # static # readonly
    FinalConcentration: str = ...  # static # readonly
    Height: str = ...  # static # readonly
    ISTDConcentrationRatio: str = ...  # static # readonly
    ISTDRelativeResponseFactor: str = ...  # static # readonly
    ISTDResponseRatio: str = ...  # static # readonly
    IntegrationEndTime: str = ...  # static # readonly
    IntegrationMetricDetail: str = ...  # static # readonly
    IntegrationMetricQualityFlags: str = ...  # static # readonly
    IntegrationQualityMetric: str = ...  # static # readonly
    IntegrationStartTime: str = ...  # static # readonly
    ManuallyIntegrated: str = ...  # static # readonly
    MassMatchScore: str = ...  # static # readonly
    MatrixSpikePercentDeviation: str = ...  # static # readonly
    MatrixSpikePercentRecovery: str = ...  # static # readonly
    QValueComputed: str = ...  # static # readonly
    ReferenceLibraryMatchScore: str = ...  # static # readonly
    RelationISTDCompoundPeak: str = ...  # static # readonly
    RelativeRetentionTime: str = ...  # static # readonly
    ResponseRatio: str = ...  # static # readonly
    RetentionTime: str = ...  # static # readonly
    RetentionTimeDifference: str = ...  # static # readonly
    SelectedGroupRetentionTime: str = ...  # static # readonly
    SelectedTargetRetentionTime: str = ...  # static # readonly
    SignalToNoiseRatio: str = ...  # static # readonly
    SurrogatePercentRecovery: str = ...  # static # readonly
    TargetResponse: str = ...  # static # readonly
    Width: str = ...  # static # readonly

class PeakQualifier:  # Class
    CoelutionScore: str = ...  # static # readonly
    ManuallyIntegrated: str = ...  # static # readonly
    QualifierResponseRatio: str = ...  # static # readonly
    SignalToNoiseRatio: str = ...  # static # readonly

class Relations:  # Class
    FKBatchTargetCompound: str = ...  # static # readonly
    FKPeakPeakQualifier: str = ...  # static # readonly
    FKTargetCompoundCalibration: str = ...  # static # readonly
    FKTargetCompoundPeak: str = ...  # static # readonly
    FKTargetCompoundTargetQualifier: str = ...  # static # readonly
    FKTargetQualifierPeakQualifier: str = ...  # static # readonly
    TargetCompoundISTDCompoundID: str = ...  # static # readonly

class TargetCompound:  # Class
    AccuracyLimitMultiplierLOQ: str = ...  # static # readonly
    AccuracyMaximumPercentDeviation: str = ...  # static # readonly
    AlternativePeakCriteria: str = ...  # static # readonly
    AreaCorrectionFactor: str = ...  # static # readonly
    AreaCorrectionMZ: str = ...  # static # readonly
    AverageRelativeRetentionTime: str = ...  # static # readonly
    AverageResponseFactor: str = ...  # static # readonly
    BatchID: str = ...  # static # readonly
    CASNumber: str = ...  # static # readonly
    CalibraionRangeFilter: str = ...  # static # readonly
    CalibrationReferenceCompoundID: str = ...  # static # readonly
    CollisionEnergy: str = ...  # static # readonly
    CompoundApproved: str = ...  # static # readonly
    CompoundGroup: str = ...  # static # readonly
    CompoundID: str = ...  # static # readonly
    CompoundMath: str = ...  # static # readonly
    CompoundName: str = ...  # static # readonly
    CompoundType: str = ...  # static # readonly
    ConcentrationUnits: str = ...  # static # readonly
    CurveFit: str = ...  # static # readonly
    CurveFitLimitHigh: str = ...  # static # readonly
    CurveFitLimitLow: str = ...  # static # readonly
    CurveFitMinimumR2: str = ...  # static # readonly
    CurveFitOrigin: str = ...  # static # readonly
    CurveFitR2: str = ...  # static # readonly
    CurveFitStatus: str = ...  # static # readonly
    CurveFitWeight: str = ...  # static # readonly
    DilutionHighestConcentration: str = ...  # static # readonly
    DilutionPattern: str = ...  # static # readonly
    ExpectedConcentration: str = ...  # static # readonly
    FragmentorVoltage: str = ...  # static # readonly
    ID: str = ...  # static # readonly
    ISTDCompoundID: str = ...  # static # readonly
    ISTDConcentration: str = ...  # static # readonly
    ISTDFlag: str = ...  # static # readonly
    ISTDResponseLimitHigh: str = ...  # static # readonly
    ISTDResponseLimitLow: str = ...  # static # readonly
    IntegrationParameters: str = ...  # static # readonly
    IntegrationParametersModified: str = ...  # static # readonly
    Integrator: str = ...  # static # readonly
    IonPolarity: str = ...  # static # readonly
    IonSource: str = ...  # static # readonly
    LeftRetentionTimeDelta: str = ...  # static # readonly
    LimitOfDetection: str = ...  # static # readonly
    LimitOfQuantitation: str = ...  # static # readonly
    MZ: str = ...  # static # readonly
    MZExtractionWindowFilterLeft: str = ...  # static # readonly
    MZExtractionWindowFilterRight: str = ...  # static # readonly
    MZExtractionWindowUnits: str = ...  # static # readonly
    MZScanRangeHigh: str = ...  # static # readonly
    MZScanRangeLow: str = ...  # static # readonly
    MatrixAConcentrationLimitHigh: str = ...  # static # readonly
    MatrixAConcentrationLimitLow: str = ...  # static # readonly
    MatrixBConcentrationLimitHigh: str = ...  # static # readonly
    MatrixBConcentrationLimitLow: str = ...  # static # readonly
    MatrixSpikeConcentration: str = ...  # static # readonly
    MatrixSpikeMaximumPercentDeviation: str = ...  # static # readonly
    MatrixSpikePercentRecoveryMaximum: str = ...  # static # readonly
    MatrixSpikePercentRecoveryMinimum: str = ...  # static # readonly
    MatrixTypeOverride: str = ...  # static # readonly
    MaximumBlankConcentration: str = ...  # static # readonly
    MaximumPercentResidual: str = ...  # static # readonly
    MinimumAverageResponseFactor: str = ...  # static # readonly
    MinimumSignalToNoiseRatio: str = ...  # static # readonly
    MolecularFormula: str = ...  # static # readonly
    Multiplier: str = ...  # static # readonly
    NeutralLossGain: str = ...  # static # readonly
    NoiseAlgorithmType: str = ...  # static # readonly
    NoiseReference: str = ...  # static # readonly
    NoiseStandardDeviationMultiplier: str = ...  # static # readonly
    PeakFilterThreshold: str = ...  # static # readonly
    PeakFilterThresholdValue: str = ...  # static # readonly
    PeakSelectionCriterion: str = ...  # static # readonly
    PlatesCalculationType: str = ...  # static # readonly
    QCMaximumDeviation: str = ...  # static # readonly
    QCMaximumPercentRSD: str = ...  # static # readonly
    QualifierRatioMethod: str = ...  # static # readonly
    QuantitateByHeight: str = ...  # static # readonly
    ReferenceMSPathName: str = ...  # static # readonly
    RelativeResponseFactorMaximumPercentDeviation: str = ...  # static # readonly
    RelativeRetentionTimeMaximumPercentDeviation: str = ...  # static # readonly
    ResolutionCalculationType: str = ...  # static # readonly
    ResponseCheckMinimum: str = ...  # static # readonly
    ResponseFactorMaximumPercentDeviation: str = ...  # static # readonly
    RetentionTime: str = ...  # static # readonly
    RetentionTimeDeltaUnits: str = ...  # static # readonly
    RetentionTimeWindow: str = ...  # static # readonly
    RetentionTimeWindowUnits: str = ...  # static # readonly
    RightRetentionTimeDelta: str = ...  # static # readonly
    RxUnlabeledIsotopicDilution: str = ...  # static # readonly
    RyLabeledIsotopicDilution: str = ...  # static # readonly
    SampleAmountLimitHigh: str = ...  # static # readonly
    SampleAmountLimitLow: str = ...  # static # readonly
    ScanType: str = ...  # static # readonly
    SelectedMZ: str = ...  # static # readonly
    Signal: str = ...  # static # readonly
    SignalInstance: str = ...  # static # readonly
    SignalName: str = ...  # static # readonly
    SignalType: str = ...  # static # readonly
    Smoothing: str = ...  # static # readonly
    SmoothingFunctionWidth: str = ...  # static # readonly
    SmoothingGaussianWidth: str = ...  # static # readonly
    SurrogateConcentration: str = ...  # static # readonly
    SurrogateConcentrationLimitHigh: str = ...  # static # readonly
    SurrogateConcentrationLimitLow: str = ...  # static # readonly
    SurrogatePercentRecoveryMaximum: str = ...  # static # readonly
    SurrogatePercentRecoveryMinimum: str = ...  # static # readonly
    SymmetryCalculationType: str = ...  # static # readonly
    TableName: str = ...  # static # readonly
    ThresholdNumberOfPeaks: str = ...  # static # readonly
    TimeReferenceFlag: str = ...  # static # readonly
    TimeSegment: str = ...  # static # readonly
    Transition: str = ...  # static # readonly
    UncertaintyRelativeOrAbsolute: str = ...  # static # readonly
    UserAnnotation: str = ...  # static # readonly
    UserDefined: str = ...  # static # readonly

class TargetQualifier:  # Class
    AreaSum: str = ...  # static # readonly
    IntegrationParameters: str = ...  # static # readonly
    IonPolarity: str = ...  # static # readonly
    MZ: str = ...  # static # readonly
    MZExtractionWindowFilterLeft: str = ...  # static # readonly
    MZExtractionWindowFilterRight: str = ...  # static # readonly
    MZExtractionWindowUnits: str = ...  # static # readonly
    PeakFilterThreshold: str = ...  # static # readonly
    PeakFilterThresholdValue: str = ...  # static # readonly
    QualifierRangeMaximum: str = ...  # static # readonly
    QualifierRangeMinimum: str = ...  # static # readonly
    RelativeResponse: str = ...  # static # readonly
    SelectedMZ: str = ...  # static # readonly
    TableName: str = ...  # static # readonly
    ThresholdNumberOfPeaks: str = ...  # static # readonly
    Transition: str = ...  # static # readonly
    Uncertainty: str = ...  # static # readonly
    UserDefined: str = ...  # static # readonly

class VirtualColumns:  # Class
    CalibrationReferenceCompoundName: str = ...  # static # readonly
    OutlierSummary: str = ...  # static # readonly
    QuantitationMessageSummary: str = ...  # static # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantAnalysis.Properties

class Resources:  # Class
    AppName: str  # static # readonly
    CmdSwitchDesc_AccountName: str  # static # readonly
    CmdSwitchDesc_Application: str  # static # readonly
    CmdSwitchDesc_Batch: str  # static # readonly
    CmdSwitchDesc_ConnectionTicket: str  # static # readonly
    CmdSwitchDesc_DefineConstant: str  # static # readonly
    CmdSwitchDesc_Domain: str  # static # readonly
    CmdSwitchDesc_Help: str  # static # readonly
    CmdSwitchDesc_Instrument: str  # static # readonly
    CmdSwitchDesc_Password: str  # static # readonly
    CmdSwitchDesc_Script: str  # static # readonly
    CmdSwitchDesc_Server: str  # static # readonly
    CmdSwitchDesc_User: str  # static # readonly
    Culture: System.Globalization.CultureInfo  # static
    ErrMsg_BatchFileNotFound: str  # static # readonly
    ErrMsg_BatchFolderContainsMultipleBatchFiles: str  # static # readonly
    ErrMsg_BatchFolderNotContainsBatchFile: str  # static # readonly
    ErrMsg_ConfigurationError: str  # static # readonly
    ErrMsg_Error: str  # static # readonly
    ErrMsg_FailedToInitializeConfiguration: str  # static # readonly
    ErrMsg_FailedToInitializeLogFile: str  # static # readonly
    ErrMsg_InvalidApplicationType: str  # static # readonly
    ErrMsg_InvalidInstrumentType: str  # static # readonly
    ErrMsg_LogonNotRequired: str  # static # readonly
    ErrMsg_LogonRequired: str  # static # readonly
    ErrMsg_ScriptFileNotFound: str  # static # readonly
    ErrMsg_SpecifyUserNameAndPassword: str  # static # readonly
    ErrMsg_TrialLicenseError: str  # static # readonly
    ErrMsg_TrialLicenseExpired: str  # static # readonly
    ErrMsg_UnknownParameter: str  # static # readonly
    Label_AppFlavor: str  # static # readonly
    Label_Flavor: str  # static # readonly
    Label_OK: str  # static # readonly
    Label_TrialVersion: str  # static # readonly
    Label_TrialVersionExpires: str  # static # readonly
    Msg_AppLocked_EnterUserNameAndPassword: str  # static # readonly
    Msg_LoggingIn: str  # static # readonly
    QuantitativeAnalysisDeskTop: System.Drawing.Icon  # static # readonly
    ResourceManager: System.Resources.ResourceManager  # static # readonly
    Title_LoggingIn: str  # static # readonly
    Usage: str  # static # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")
from .UIScriptIF import IUIState

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.RunQueryHost

class Host(System.MarshalByRefObject):  # Class
    def __init__(self, state: IUIState) -> None: ...

    CompilerType: str

    def Run(self, queryFile: str) -> None: ...
    def SetImports(self, imports: List[str]) -> None: ...
    def SetReferences(self, references: List[str]) -> None: ...
    def SetCompilerOption(self, key: str, value_: str) -> None: ...

class QueryResultsWindow(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, state: IUIState) -> None: ...

    RunQuery: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.RunQueryHost.RunQueryBase
    )

class RunQueryBase(System.MarshalByRefObject):  # Class
    WindowTitle: str  # readonly

    def GetColumnFormat(self, column: str) -> str: ...
    def GetColumnLabels(self, column: str) -> str: ...
    def QueryMain(self) -> Any: ...

class _BindingList(
    System.ComponentModel.IBindingList,
    Generic[T],
    System.ComponentModel.IRaiseItemChangedEvents,
    Sequence[T],
    System.ComponentModel.BindingList[T],
    List[Any],
    List[T],
    Iterable[T],
    System.ComponentModel.ICancelAddNew,
    Sequence[Any],
    Iterable[Any],
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, list: List[T]) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import (
    UI,
    AppCommand,
    Configuration,
    DataCommand,
    ScriptIF,
    ScriptIFImpls,
    Tools,
    UAControls,
    Utils,
)

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit

class CommandLine:  # Class
    def __init__(self) -> None: ...

    AccountName: str
    ConnectionTicket: str
    Culture: str
    Domain: str
    EncryptedPassword: str
    Method: str
    Password: str
    Server: str
    UnknownsAnalysis: bool
    User: str

class ReportMethodEditException(
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
    System.Exception,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, innerException: System.Exception) -> None: ...
    @overload
    def __init__(
        self,
        info: System.Runtime.Serialization.SerializationInfo,
        context: System.Runtime.Serialization.StreamingContext,
    ) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")
from . import TitledPanel

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Controls.PropertiesGrid

class PropertiesGridControl(
    System.Windows.Forms.ComponentModel.Com2Interop.IComPropertyBrowser,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.PropertyGrid,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.IBindableComponent,
    System.ComponentModel.IComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.IDisposable,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPropertyNotifySink,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
):  # Class
    def __init__(self) -> None: ...
    def Refresh(self) -> None: ...

class PropertiesGridPane(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    TitledPanel,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    PropertiesGridControl: (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Controls.PropertiesGrid.PropertiesGridControl
    )  # readonly

class QuickSort(Generic[T]):  # Class
    def __init__(
        self,
        values: System.ComponentModel.BindingList[T],
        comparison: System.Comparison[T],
    ) -> None: ...
    def Sort(self) -> None: ...

class SpectrumEditor(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

class SpectrumObject:  # Class
    def __init__(
        self,
        uiContext: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.UIContext,
        key: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Utils.SpectrumKey,
        control: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Controls.PropertiesGrid.PropertiesGridControl,
    ) -> None: ...

class SpectrumObjectConverter(System.ComponentModel.TypeConverter):  # Class
    def __init__(self) -> None: ...
    def GetProperties(
        self,
        context: System.ComponentModel.ITypeDescriptorContext,
        value_: Any,
        attributes: List[System.Attribute],
    ) -> System.ComponentModel.PropertyDescriptorCollection: ...
    def GetPropertiesSupported(
        self, context: System.ComponentModel.ITypeDescriptorContext
    ) -> bool: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import SampleRowID, UnknownsAnalysisDataSet
from .Command import CommandContext
from .ReportResults import (
    IUnknownsAnalysisDataProvider,
    IUnknownsAnalysisDataReader,
    IUnknownsAnalysisGraphics,
)

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.ReportDataProvider

class UnknownsAnalysisDataProvider(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IReportDataProvider,
    System.IDisposable,
    IUnknownsAnalysisDataProvider,
):  # Class
    def __init__(self, context: CommandContext) -> None: ...

    AbortEventName: str
    AnalysisFileName: str  # readonly
    AuditTrailDataSet: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.AuditTrailDataSet
    )  # readonly
    BatchPath: str  # readonly
    Compliance: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IReportCompliance
    )  # readonly
    CurrentVersion: str  # readonly
    FixedGraphics: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IFixedGraphics
    )
    IsAuditTrailing: bool  # readonly
    MethodPath: str
    ReportContext: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IReportContext
    )  # readonly
    TargetSamples: List[SampleRowID]
    TemplatePath: str

    def GetTargetQualifier(
        self,
        batchID: Optional[int],
        sampleID: Optional[int],
        compoundID: Optional[int],
        qualifierID: Optional[int],
        table: UnknownsAnalysisDataSet.TargetQualifierDataTable,
    ) -> int: ...
    def GetPeakQualifier(
        self,
        batchID: Optional[int],
        sampleID: Optional[int],
        compoundID: Optional[int],
        qualifierID: Optional[int],
        peakID: Optional[int],
        table: UnknownsAnalysisDataSet.PeakQualifierDataTable,
    ) -> int: ...
    def GetComponent(
        self,
        batchID: Optional[int],
        sampleID: Optional[int],
        deconvolutionMethodID: Optional[int],
        componentID: Optional[int],
        table: UnknownsAnalysisDataSet.ComponentDataTable,
    ) -> int: ...
    def FormatNumber(self, columnName: str, value_: float) -> str: ...
    def IsAttemptingAbort(self) -> bool: ...
    def GetDeconvolutionMethod(
        self,
        batchID: Optional[int],
        sampleID: Optional[int],
        deconvolutionMethodID: Optional[int],
        table: UnknownsAnalysisDataSet.DeconvolutionMethodDataTable,
    ) -> int: ...
    def TranslateEnumValue(
        self, tableName: str, columnName: str, value_: str
    ) -> str: ...
    def Dispose(self) -> None: ...
    def CheckAbortSignal(self) -> None: ...
    def GetSample(
        self,
        batchID: Optional[int],
        sampleID: Optional[int],
        table: UnknownsAnalysisDataSet.SampleDataTable,
    ) -> int: ...
    def GetTargetCompound(
        self,
        batchId: Optional[int],
        sampleID: Optional[int],
        compoundID: Optional[int],
        table: UnknownsAnalysisDataSet.TargetCompoundDataTable,
    ) -> int: ...
    def GetBatch(
        self, batchID: Optional[int], table: UnknownsAnalysisDataSet.BatchDataTable
    ) -> int: ...
    def GetNumberFormat(self, columnName: str) -> str: ...
    def GetAuxiliaryMethod(
        self,
        batchID: Optional[int],
        sampleID: Optional[int],
        table: UnknownsAnalysisDataSet.AuxiliaryMethodDataTable,
    ) -> int: ...
    def FormatDateTime(self, columnName: str, value_: System.DateTime) -> str: ...
    def GetHitsFromMethod(
        self,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: Optional[int],
        identificationMethodID: Optional[int],
        table: UnknownsAnalysisDataSet.HitDataTable,
    ) -> int: ...
    def ProgressMessage(self, pageNumber: int, message: str) -> None: ...
    def GetAnalysis(self, table: UnknownsAnalysisDataSet.AnalysisDataTable) -> int: ...
    def GetExactMass(
        self,
        batchID: Optional[int],
        sampleID: Optional[int],
        deconvolutionMethodID: Optional[int],
        componentID: Optional[int],
        hitID: Optional[int],
        exactMassID: Optional[int],
        table: UnknownsAnalysisDataSet.ExactMassDataTable,
    ) -> int: ...
    def GetLibrarySearchMethod(
        self,
        batchID: Optional[int],
        sampleID: Optional[int],
        identificationMethodID: Optional[int],
        librarySearchMethodID: Optional[int],
        table: UnknownsAnalysisDataSet.LibrarySearchMethodDataTable,
    ) -> int: ...
    def ExecuteReader(
        self, batchID: int, sampleID: int, select: str
    ) -> IUnknownsAnalysisDataReader: ...
    def GetTargetMatchMethod(
        self,
        batchID: Optional[int],
        sampleID: Optional[int],
        targetMatchMethodID: Optional[int],
        table: UnknownsAnalysisDataSet.TargetMatchMethodDataTable,
    ) -> int: ...
    def GetIonPeak(
        self,
        batchID: Optional[int],
        sampleID: Optional[int],
        deconvolutionMethodID: Optional[int],
        componentID: Optional[int],
        ionPeakID: Optional[int],
        table: UnknownsAnalysisDataSet.IonPeakDataTable,
    ) -> int: ...
    def CreateGraphics(self) -> IUnknownsAnalysisGraphics: ...
    def GetPeak(
        self,
        batchID: Optional[int],
        sampleID: Optional[int],
        compoundID: Optional[int],
        peakID: Optional[int],
        table: UnknownsAnalysisDataSet.PeakDataTable,
    ) -> int: ...
    def GetHit(
        self,
        batchID: Optional[int],
        sampleID: Optional[int],
        deconvolutionMethodID: Optional[int],
        componentID: Optional[int],
        hitID: Optional[int],
        table: UnknownsAnalysisDataSet.HitDataTable,
    ) -> int: ...
    def GetIdentificationMethod(
        self,
        batchID: Optional[int],
        sampleID: Optional[int],
        identificationMethodID: Optional[int],
        table: UnknownsAnalysisDataSet.IdentificationMethodDataTable,
    ) -> int: ...

class UnknownsAnalysisDataReader(
    System.IDisposable, IUnknownsAnalysisDataReader
):  # Class
    def __getitem__(self, name: str) -> Any: ...
    def IsDBNull(self, name: str) -> bool: ...
    def Read(self) -> bool: ...
    def Dispose(self) -> None: ...

class UnknownsAnalysisGraphics(System.IDisposable, IUnknownsAnalysisGraphics):  # Class
    def __init__(
        self,
        provider: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.ReportDataProvider.UnknownsAnalysisDataProvider,
    ) -> None: ...
    @overload
    def DrawSampleChromatogram(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        batchId: int,
        sampleId: int,
        width: float,
        height: float,
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawSampleChromatogram(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        batchId: int,
        sampleId: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawHitLibrarySpectrum(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        hitID: int,
        width: float,
        height: float,
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawHitLibrarySpectrum(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        hitID: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawComponentSpectrum(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        width: float,
        height: float,
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawComponentSpectrum(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
    ) -> iTextSharp.text.Image: ...
    def DrawStructure(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        hitID: int,
        width: float,
        height: float,
    ) -> iTextSharp.text.Image: ...
    def GetComponentSpectrumRange(
        self,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        minx: float,
        maxx: float,
    ) -> None: ...
    def GetSampleChromatogramRange(
        self, batchId: int, sampleId: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.GraphicsRange
    ): ...
    @overload
    def DrawIonPeaks(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        width: float,
        height: float,
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawIonPeaks(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        width: float,
        height: float,
        showTic: bool,
        showComponent: bool,
        showIons: bool,
        showLabels: bool,
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawIonPeaks(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        width: float,
        height: float,
        showTic: bool,
        showComponent: bool,
        showIons: bool,
        showLabels: bool,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawEicPeaks(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        width: float,
        height: float,
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawEicPeaks(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> iTextSharp.text.Image: ...
    def GetHitLibrarySpectrumRange(
        self,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        hitID: int,
        minx: float,
        maxx: float,
    ) -> None: ...
    def Dispose(self) -> None: ...
    @overload
    def DrawExtractedSpectrum(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        width: float,
        height: float,
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawExtractedSpectrum(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
    ) -> iTextSharp.text.Image: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import Properties
from .Compliance import ICompliance, ILogonParameters
from .UIUtils2 import ConfigurationElementSectionBase

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff

class App(
    System.Windows.Application,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IHaveResources,
):  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def Main() -> None: ...

class AppConfig:  # Class
    ApplicationSettings: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.ApplicationSettings
    )  # readonly
    Instance: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.AppConfig
    )  # static # readonly
    UserSettings: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.UserSettings
    )  # readonly

    def Save(self) -> None: ...

class ApplicationSettings(ConfigurationElementSectionBase):  # Class
    def __init__(self) -> None: ...

    DumpLogOnNormalExit: bool  # readonly
    ErrorReportingEmailAddress: str  # readonly
    ErrorReportingEnabled: bool  # readonly

class CmdLine(ILogonParameters):  # Class
    def __init__(self) -> None: ...

    AccountName: str
    CompareMode: bool
    ConnectionTicket: str
    Culture: str
    Domain: str
    EncryptedPassword: str
    Help: bool
    HistoryMode: bool
    Methods: List[str]
    Password: str
    Server: str
    User: str
    _Password: System.Security.SecureString  # readonly

class DiffInfo:  # Class
    def __init__(self) -> None: ...

    Column: str
    Description: str
    DiffType: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.DiffType
    Table: str
    Value1: Any
    Value2: Any

class DiffType(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
    Deleted: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.DiffType = (
        ...
    )  # static # readonly
    Inserted: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.DiffType = (
        ...
    )  # static # readonly
    Modified: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.DiffType = (
        ...
    )  # static # readonly

class DiffWindow(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Window,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IWindowService,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class DiffWindowModel:  # Class
    def __init__(self) -> None: ...

    Differences: Iterable[Any]
    Pathname1: str
    Pathname2: str

class DirDiffInfo:  # Class
    def __init__(
        self,
        type: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.MethodItemType,
    ) -> None: ...

    CanShowDetails: bool  # readonly
    Differences: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.DiffInfo
    ]
    Different: bool  # readonly
    DisplayName: str
    File1Exists: bool
    File2Exists: bool
    RelativePath: str
    Type: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.MethodItemType
    )  # readonly

class MainWindow(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Window,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IWindowService,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...
    def OpenMethods(self, method1: str, method2: str) -> None: ...

class MethodHistoryItem(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.NotifyPropertyBase,
    System.ComponentModel.INotifyPropertyChanged,
):  # Class
    def __init__(
        self,
        type: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.MethodItemType,
    ) -> None: ...

    DisplayName: str
    RelativePath: str
    RevisionDifferences: System.Collections.ObjectModel.ObservableCollection[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.MethodHistoryItemRevision
    ]  # readonly
    Type: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.MethodItemType
    )  # readonly

class MethodHistoryItemRevision:  # Class
    def __init__(self) -> None: ...

    CanShowDetails: bool  # readonly
    Date: Optional[System.DateTime]
    Differences: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.DiffInfo
    ]
    File1Exists: bool
    File2Exists: bool
    Identical: bool  # readonly
    Reason: str
    Revision1: str
    Revision2: str
    User: str

class MethodHistoryModel(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.NotifyPropertyBase,
    System.ComponentModel.INotifyPropertyChanged,
):  # Class
    def __init__(self) -> None: ...

    CommandBrowse: System.Windows.Input.ICommand  # readonly
    CommandGenerateHistory: System.Windows.Input.ICommand  # readonly
    CommandReport: System.Windows.Input.ICommand  # readonly
    Compliance: ICompliance
    Items: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.MethodHistoryItem
    ]  # readonly
    MethodPath: str
    Progress: float  # readonly
    ProgressMessage: str
    Revisions: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.MethodHistoryRevision
    ]  # readonly
    ShowDetailsCommand: System.Windows.Input.ICommand  # readonly
    Window: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.MethodHistoryWindow
    )

    def GenerateHistory(self) -> None: ...

class MethodHistoryRevision:  # Class
    def __init__(self) -> None: ...

    Date: Optional[System.DateTime]
    Reason: str
    RevisionNumber: str
    User: str
    _Date: str  # readonly

class MethodHistoryWindow(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Window,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IWindowService,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...
    def OpenMethod(self, method: str) -> None: ...
    def InitializeComponent(self) -> None: ...

class MethodItemType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Quant: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.MethodItemType
    ) = ...  # static # readonly
    QuantReport: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.MethodItemType
    ) = ...  # static # readonly
    Unknowns: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.MethodItemType
    ) = ...  # static # readonly
    UnknownsReport: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.MethodItemType
    ) = ...  # static # readonly

class Model(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.NotifyPropertyBase,
    System.ComponentModel.INotifyPropertyChanged,
):  # Class
    def __init__(self) -> None: ...

    BrowseCommand: System.Windows.Input.ICommand  # readonly
    CloseCommand: System.Windows.Input.ICommand  # readonly
    CompareCommand: System.Windows.Input.ICommand  # readonly
    Compliance: ICompliance
    DirectoryDifferences: Iterable[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.DirDiffInfo
    ]  # readonly
    GridVisibility: System.Windows.Visibility  # readonly
    Pathname1: str
    Pathname2: str
    Revision1: str
    Revision2: str
    RevisionVisibility: System.Windows.Visibility  # readonly
    ShowDetailsCommand: System.Windows.Input.ICommand  # readonly
    Window: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.MainWindow

    def Compare(self) -> None: ...
    @staticmethod
    def _CompareFiles(
        path1: str, path2: str
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.DiffInfo
    ]: ...

class NotifyPropertyBase(System.ComponentModel.INotifyPropertyChanged):  # Class
    def VerifyPropertyName(self, propertyName: str) -> None: ...

    PropertyChanged: System.ComponentModel.PropertyChangedEventHandler  # Event

class ProgressWindow(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Window,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IWindowService,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class RelayCommand(System.Windows.Input.ICommand):  # Class
    @overload
    def __init__(self, execute: System.Action) -> None: ...
    @overload
    def __init__(
        self, execute: System.Action, canExecute: System.Predicate
    ) -> None: ...
    def CanExecute(self, parameter: Any) -> bool: ...
    def Execute(self, parameter: Any) -> None: ...

    CanExecuteChanged: System.EventHandler  # Event

class Report(iTextSharp.text.pdf.IPdfPageEvent):  # Class
    def __init__(
        self, compliance: ICompliance, methodPath: str, stream: System.IO.Stream
    ) -> None: ...
    @staticmethod
    def RegisterFont(name: str) -> None: ...
    def OnEndPage(
        self, writer: iTextSharp.text.pdf.PdfWriter, document: iTextSharp.text.Document
    ) -> None: ...
    def OnGenericTag(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        document: iTextSharp.text.Document,
        rect: iTextSharp.text.Rectangle,
        text: str,
    ) -> None: ...
    def OnOpenDocument(
        self, writer: iTextSharp.text.pdf.PdfWriter, document: iTextSharp.text.Document
    ) -> None: ...
    def OnParagraph(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        document: iTextSharp.text.Document,
        paragraphPosition: float,
    ) -> None: ...
    def OnSection(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        document: iTextSharp.text.Document,
        paragraphPosition: float,
        depth: int,
        title: iTextSharp.text.Paragraph,
    ) -> None: ...
    @staticmethod
    def GetFont(name: str) -> iTextSharp.text.Font: ...
    def OnChapterEnd(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        document: iTextSharp.text.Document,
        paragraphPosition: float,
    ) -> None: ...
    def OnStartPage(
        self, writer: iTextSharp.text.pdf.PdfWriter, document: iTextSharp.text.Document
    ) -> None: ...
    def OnChapter(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        document: iTextSharp.text.Document,
        paragraphPosition: float,
        title: iTextSharp.text.Paragraph,
    ) -> None: ...
    def OnCloseDocument(
        self, writer: iTextSharp.text.pdf.PdfWriter, document: iTextSharp.text.Document
    ) -> None: ...
    @staticmethod
    def GetDefaultFontNameByCulture(ci: System.Globalization.CultureInfo) -> str: ...
    def OnParagraphEnd(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        document: iTextSharp.text.Document,
        paragraphPosition: float,
    ) -> None: ...
    def OnSectionEnd(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        document: iTextSharp.text.Document,
        paragraphPosition: float,
    ) -> None: ...
    def Generate(
        self,
        revisions: Iterable[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.MethodHistoryRevision
        ],
        items: Iterable[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.MethodHistoryItem
        ],
    ) -> None: ...

class SelectAllCommand(System.Windows.Input.ICommand):  # Class
    def __init__(self) -> None: ...
    def IterateRecords(
        self, records: Infragistics.Windows.DataPresenter.RecordCollectionBase
    ) -> None: ...
    def CanExecute(self, parameter: Any) -> bool: ...
    def Execute(self, parameter: Any) -> None: ...

    CanExecuteChanged: System.EventHandler  # Event

class UserSettings(ConfigurationElementSectionBase):  # Class
    def __init__(self) -> None: ...

    LastMethodFolder: str



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
TEvent = TypeVar("TEvent")
TEventArgs = TypeVar("TEventArgs")

# Stubs for namespace: Agilent.OpenLab.Framework.Common.Notification

class IInfrastructureEvent(object):  # Interface
    def Reset(self) -> None: ...

class InfrastructureEventBase(
    Generic[TEventArgs],
    Agilent.OpenLab.Framework.Common.Notification.IInfrastructureEvent,
):  # Class
    Actions: List[System.Action[TEventArgs]]  # readonly

    def Unsubscribe(self, action: System.Action[TEventArgs]) -> None: ...
    def Reset(self) -> None: ...
    def Subscribe(self, action: System.Action[TEventArgs]) -> None: ...

class NotificationServiceBase:  # Class
    def Subscribe(self, action: System.Action[TEventArgs]) -> None: ...
    def Unsubscribe(self, action: System.Action[TEventArgs]) -> None: ...
    def Raise(self, args: TEventArgs) -> None: ...
    def Get(self) -> TEvent: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import ProcessTask, ReportFilterItem
from .Controls2 import IWizardPage

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportWizard

class EditProcessTaskDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    Task: ProcessTask

class EditProcessTasksDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...
    def InitTasks(self, tasks: Iterable[ProcessTask]) -> None: ...
    def GetTasks(self) -> List[ProcessTask]: ...

class FileNameCell(
    System.IDisposable, System.ICloneable, System.Windows.Forms.DataGridViewTextBoxCell
):  # Class
    def __init__(self) -> None: ...

class IGenerateReportWizardPage(IWizardPage, System.IDisposable):  # Interface
    def ValidatePage(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportWizard.WizardError
    ]: ...

class SelectRowsDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...
    def GetSelectedItems(self) -> Iterable[ReportFilterItem]: ...

class WizardError:  # Class
    def __init__(self, message: str, control: System.Windows.Forms.Control) -> None: ...

    Control: System.Windows.Forms.Control  # readonly
    Message: str  # readonly
